# Simulated Annealing Allocation Tool (SAAT)

## Install

**Git**
```
git clone https://github.com/samuelweller21/SAAT.git
cd SAAT
```

**Install dependencies**

```
# Intall [poetry](https://python-poetry.org/docs/#installing-with-the-official-installer)
poetry shell
poetry install

# Jupyter
python3 -m ipykernel install --user --name="SAAT" --display-name="SAAT"
```

**Run tests**
```
pytest
```

See [Demo.ipynb](https://github.com/samuelweller21/SAAT/blob/main/Demo.ipynb) for example of use
